OptionResolver

Struct OptionResolver 

pub struct OptionResolver {
    pub base_uri: String,
    pub hudi_options: HashMap<String, String>,
    pub storage_options: HashMap<String, String>,
    pub options: HashMap<String, String>,
}
Resolver for options including Hudi options, storage options, and generic options.

Fields

base_uri: Stringhudi_options: HashMap<String, String>storage_options: HashMap<String, String>options: HashMap<String, String>

Implementations

Source

impl OptionResolver

pub fn new(base_uri: &str) -> OptionResolver

Create a new OptionResolver with the given base URI.

pub fn new_with_options<I, K, V>(base_uri: &str, options: I) -> OptionResolver
where I: IntoIterator<Item = (K, V)>, K: AsRef<str>, V: Into<String>,

Create a new OptionResolver with the given base URI and options.

pub async fn resolve_options(&mut self) -> Result<(), CoreError>

Resolve all options by combining the ones from hoodie.properties, user-provided options, env vars, and global Hudi configs. The precedence order is as follows:

  1. hoodie.properties
  2. Explicit options provided by the user
  3. Generic options provided by the user
  4. Env vars
  5. Global Hudi configs

[note] Error may occur when 1 and 2 have conflicts.