pub struct OptionResolver {
pub base_uri: String,
pub hudi_options: HashMap<String, String>,
pub storage_options: HashMap<String, String>,
pub options: HashMap<String, String>,
}Expand description
Resolver for options including Hudi options, storage options, and generic options.
Fields
base_uri: Stringhudi_options: HashMap<String, String>storage_options: HashMap<String, String>options: HashMap<String, String>Implementations
Sourceimpl OptionResolver
impl OptionResolver
Sourcepub fn new(base_uri: &str) -> OptionResolver
pub fn new(base_uri: &str) -> OptionResolver
Create a new OptionResolver with the given base URI.
Sourcepub fn new_with_options<I, K, V>(base_uri: &str, options: I) -> OptionResolver
pub fn new_with_options<I, K, V>(base_uri: &str, options: I) -> OptionResolver
Create a new OptionResolver with the given base URI and options.
Sourcepub async fn resolve_options(&mut self) -> Result<(), CoreError>
pub async fn resolve_options(&mut self) -> Result<(), CoreError>
Resolve all options by combining the ones from hoodie.properties, user-provided options, env vars, and global Hudi configs. The precedence order is as follows:
- hoodie.properties
- Explicit options provided by the user
- Generic options provided by the user
- Env vars
- Global Hudi configs
[note] Error may occur when 1 and 2 have conflicts.